@@ -16,18 +16,18 @@ Email::Send::YYClouds - Send simple mail using smtp relay server
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 
 =head1 SYNOPSIS
 
 This module sends text based simple mail with any smtp relay server, default localhost.
 
-If you find any issues in using the module, please don't hesitate to email me: opensoft [at] posthub.me
+If you find any issues in using the module, please don't hesitate to email me: pyh@crypt.pw
 
 
     use Email::Send::YYClouds;
